@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::nop;
+package Dist::Zilla::App::Command::nop 6.010;
 # ABSTRACT: initialize dzil, then exit
-$Dist::Zilla::App::Command::nop::VERSION = '5.020';
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -19,6 +19,11 @@ use Dist::Zilla::App -command;
 
 sub abstract { 'do nothing: initialize dzil, then exit' }
 
+sub description {
+  "This command does nothing but initialize Dist::Zilla and exit.\n" .
+  "It is sometimes useful for diagnostic purposes."
+}
+
 sub execute {
   my ($self, $opt, $arg) = @_;
 
@@ -39,7 +44,7 @@ Dist::Zilla::App::Command::nop - initialize dzil, then exit
 
 =head1 VERSION
 
-version 5.020
+version 6.010
 
 =head1 SYNOPSIS
 
@@ -53,11 +58,11 @@ overthink it, okay?
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2017 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
