@@ -1,6 +1,6 @@
-package Dist::Zilla::Chrome::Term;
+package Dist::Zilla::Chrome::Term 6.010;
 # ABSTRACT: chrome used for terminal-based interaction
-$Dist::Zilla::Chrome::Term::VERSION = '5.043';
+
 use Moose;
 
 #pod =head1 OVERVIEW
@@ -21,7 +21,8 @@ has logger => (
   isa => 'Log::Dispatchouli',
   init_arg => undef,
   writer   => '_set_logger',
-  lazy_build => 1,
+  lazy => 1,
+  builder => '_build_logger',
 );
 
 sub _build_logger {
@@ -35,11 +36,11 @@ sub _build_logger {
   }
 
   return Log::Dispatchouli->new({
-      ident     => 'Dist::Zilla',
-      to_stdout => 1,
-      log_pid   => 0,
-      to_self   => ($ENV{DZIL_TESTING} ? 1 : 0),
-      quiet_fatal => 'stdout',
+    ident     => 'Dist::Zilla',
+    to_stdout => 1,
+    log_pid   => 0,
+    to_self   => ($ENV{DZIL_TESTING} ? 1 : 0),
+    quiet_fatal => 'stdout',
   });
 }
 
@@ -85,7 +86,7 @@ sub prompt_str {
   }
   my $input_bytes = $self->term_ui->get_reply(
     prompt => $encode->($prompt),
-    allow  => $check || sub { defined $_[0] and length $_[0] },
+    allow  => $check || sub { length $_[0] },
     (defined $default
       ? (default => $encode->($default))
       : ()
@@ -109,6 +110,16 @@ sub prompt_yn {
   $arg ||= {};
   my $default = $arg->{default};
 
+  if (! $self->_isa_tty) {
+    if (defined $default) {
+      return OneZero->coerce($default);
+    }
+
+    $self->logger->log_fatal(
+      "want interactive input, but terminal doesn't appear interactive"
+    );
+  }
+
   my $input = $self->term_ui->ask_yn(
     prompt  => $prompt,
     (defined $default ? (default => OneZero->coerce($default)) : ()),
@@ -117,11 +128,16 @@ sub prompt_yn {
   return $input;
 }
 
+sub _isa_tty {
+  my $isa_tty = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
+  return $isa_tty;
+}
+
 sub prompt_any_key {
   my ($self, $prompt) = @_;
   $prompt ||= 'press any key to continue';
 
-  my $isa_tty = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
+  my $isa_tty = $self->_isa_tty;
 
   if ($isa_tty) {
     local $| = 1;
@@ -152,7 +168,7 @@ Dist::Zilla::Chrome::Term - chrome used for terminal-based interaction
 
 =head1 VERSION
 
-version 5.043
+version 6.010
 
 =head1 OVERVIEW
 
@@ -161,11 +177,11 @@ terminal environment.  It's the default chrome used by L<Dist::Zilla::App>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2017 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
