@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::PkgDist;
+package Dist::Zilla::Plugin::PkgDist 6.010;
 # ABSTRACT: add a $DIST to your packages
-$Dist::Zilla::Plugin::PkgDist::VERSION = '5.043';
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -91,13 +91,17 @@ sub munge_perl {
       $file->name,
     ]);
 
+    # the extra whitespace element ensures we don't swallow up any blanks
+    # lines after 'package ...' in the source file that PkgVersion warns about
+    # if it's missing.
     Carp::carp('error inserting $DIST in ' . $file->name)
-      unless $stmt->insert_after($children[0]->clone)
+      unless $stmt->add_element( PPI::Token::Whitespace->new("\n") )
+      and    $stmt->insert_after($children[0]->clone)
       and    $stmt->insert_after( PPI::Token::Whitespace->new("\n") );
   }
 
   # the document is no longer correct; it must be reparsed before it can be used again
-  $file->encoded_content($document->serialize);
+  $file->content($document->serialize);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -115,7 +119,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 5.043
+version 6.010
 
 =head1 DESCRIPTION
 
@@ -135,11 +139,11 @@ typically used when doing monkey patching or other tricky things.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2017 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
