@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::FakeClassic;
+package Dist::Zilla::PluginBundle::FakeClassic 6.010;
 # ABSTRACT: build something more or less like a "classic" CPAN dist
-$Dist::Zilla::PluginBundle::FakeClassic::VERSION = '5.043';
+
 use Moose;
 extends 'Dist::Zilla::PluginBundle::Classic';
 
@@ -40,15 +40,15 @@ Dist::Zilla::PluginBundle::FakeClassic - build something more or less like a "cl
 
 =head1 VERSION
 
-version 5.043
+version 6.010
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2017 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
