@@ -1,4 +1,4 @@
-package Dist::Zilla::Role::PPI 6.008;
+package Dist::Zilla::Role::PPI 6.010;
 # ABSTRACT: a role for plugins which use PPI
 
 use Moose::Role;
@@ -68,7 +68,7 @@ sub save_ppi_document_to_file {
 
 #pod =method document_assigns_to_variable
 #pod
-#pod   if( $self->ppi_document_for_file($document, '$FOO')) { ... }
+#pod   if( $self->document_assigns_to_variable($document, '$FOO')) { ... }
 #pod
 #pod This method returns true if the document assigns to the given variable (the
 #pod sigil must be included).
@@ -127,7 +127,7 @@ Dist::Zilla::Role::PPI - a role for plugins which use PPI
 
 =head1 VERSION
 
-version 6.008
+version 6.010
 
 =head1 DESCRIPTION
 
@@ -157,7 +157,7 @@ It also updates the internal PPI document cache with the new document.
 
 =head2 document_assigns_to_variable
 
-  if( $self->ppi_document_for_file($document, '$FOO')) { ... }
+  if( $self->document_assigns_to_variable($document, '$FOO')) { ... }
 
 This method returns true if the document assigns to the given variable (the
 sigil must be included).
@@ -168,7 +168,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2017 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
